<?php

namespace Assetdocs\Incidentpkgs\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Form;
use Assetdocs\Incidentpkgs\Http\Requests\IncidentpkgAdminWebRequest;
use Assetdocs\Incidentpkgs\Interfaces\IncidentpkgRepositoryInterface;
use Assetdocs\Incidentpkgs\Models\Incidentpkg;

/**
 * Admin web controller class.
 */
class IncidentpkgAdminController extends BaseController
{
    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'admin.web';

    /**
     * Initialize incidentpkg controller.
     *
     * @param type IncidentpkgRepositoryInterface $incidentpkg
     *
     * @return type
     */
    public function __construct(IncidentpkgRepositoryInterface $incidentpkg)
    {
        $this->middleware('web');
        $this->middleware('auth:admin.web');
        $this->setupTheme(config('theme.themes.admin.theme'), config('theme.themes.admin.layout'));

        $this->repository = $incidentpkg;
        parent::__construct();
    }

    /**
     * Display a list of incidentpkg.
     *
     * @return Response
     */
    public function index(IncidentpkgAdminWebRequest $request)
    {
        $pageLimit = $request->input('pageLimit');
        if ($request->wantsJson()) {
            $incidentpkgs  = $this->repository
            ->pushCriteria(new \Assetdocs\Incidentpkgs\Repositories\Criteria\IncidentpkgAdminCriteria())
                ->setPresenter('\\Assetdocs\\Incidentpkgs\\Repositories\\Presenter\\IncidentpkgListPresenter')
                ->scopeQuery(function ($query) {
                    return $query->orderBy('id', 'DESC');
                })->paginate($pageLimit);

            $incidentpkgs['recordsTotal']    = $incidentpkgs['meta']['pagination']['total'];
            $incidentpkgs['recordsFiltered'] = $incidentpkgs['meta']['pagination']['total'];
            $incidentpkgs['request']         = $request->all();
            return response()->json($incidentpkgs, 200);

        }

        $this   ->theme->prependTitle(trans('incidentpkgs::incidentpkg.names').' :: ');
        return $this->theme->of('incidentpkgs::admin.incidentpkg.index')->render();
    }

    /**
     * Display incidentpkg.
     *
     * @param Request $request
     * @param Model   $incidentpkg
     *
     * @return Response
     */
    public function show(IncidentpkgAdminWebRequest $request, Incidentpkg $incidentpkg)
    {
        if (!$incidentpkg->exists) {
            return response()->view('incidentpkgs::admin.incidentpkg.new', compact('incidentpkg'));
        }

        Form::populate($incidentpkg);
        return response()->view('incidentpkgs::admin.incidentpkg.show', compact('incidentpkg'));
    }

    /**
     * Show the form for creating a new incidentpkg.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(IncidentpkgAdminWebRequest $request)
    {

        $incidentpkg = $this->repository->newInstance([]);

        Form::populate($incidentpkg);

        return response()->view('incidentpkgs::admin.incidentpkg.create', compact('incidentpkg'));

    }

    /**
     * Create new incidentpkg.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(IncidentpkgAdminWebRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.web');
            $incidentpkg          = $this->repository->create($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('incidentpkgs::incidentpkg.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/incidentpkgs/incidentpkg/'.$incidentpkg->getRouteKey())
            ], 201);


        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
            ], 400);
        }
    }

    /**
     * Show incidentpkg for editing.
     *
     * @param Request $request
     * @param Model   $incidentpkg
     *
     * @return Response
     */
    public function edit(IncidentpkgAdminWebRequest $request, Incidentpkg $incidentpkg)
    {
        Form::populate($incidentpkg);
        return  response()->view('incidentpkgs::admin.incidentpkg.edit', compact('incidentpkg'));
    }

    /**
     * Update the incidentpkg.
     *
     * @param Request $request
     * @param Model   $incidentpkg
     *
     * @return Response
     */
    public function update(IncidentpkgAdminWebRequest $request, Incidentpkg $incidentpkg)
    {
        try {

            $attributes = $request->all();

            $incidentpkg->update($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('incidentpkgs::incidentpkg.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/incidentpkgs/incidentpkg/'.$incidentpkg->getRouteKey())
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/incidentpkgs/incidentpkg/'.$incidentpkg->getRouteKey()),
            ], 400);

        }
    }

    /**
     * Remove the incidentpkg.
     *
     * @param Model   $incidentpkg
     *
     * @return Response
     */
    public function destroy(IncidentpkgAdminWebRequest $request, Incidentpkg $incidentpkg)
    {

        try {

            $t = $incidentpkg->delete();

            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('incidentpkgs::incidentpkg.name')]),
                'code'     => 202,
                'redirect' => trans_url('/admin/incidentpkgs/incidentpkg/0'),
            ], 202);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/incidentpkgs/incidentpkg/'.$incidentpkg->getRouteKey()),
            ], 400);
        }
    }
}
